@@ -78,7 +78,10 @@ class InnerProcessWrap:
                     except:
                         self.return_value = None
                     finally:
-                        self.parent_conn.close()
+                        try:
+                            self.parent_conn.close() # close it, if it can be closed
+                        except:
+                            pass
                 update_dic = { # 程序已经运行结束
                     "status": "TERM",
                     "info": {
